@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# OPTIONS -fglasgow-exts #-}
 
 -- These are simple tests to observe (data)type representations.
@@ -16,8 +17,10 @@ data MyDataType a = MyDataType a
 -- Some terms and corresponding type representations
 myTerm     = undefined :: MyDataType Int
 myTypeRep  = typeOf myTerm            -- type representation in Typeable
-myTyCon    = typeRepTyCon myTypeRep   -- type constructor via Typeable
 myDataType = dataTypeOf myTerm        -- datatype representation in Data
+
+#if MIN_VERSION_base(4,5,0)
+myTyCon    = typeRepTyCon myTypeRep   -- type constructor via Typeable
 myString1  = tyConName myTyCon        -- type constructor via Typeable
 myString2  = dataTypeName myDataType  -- type constructor via Data
 
@@ -29,6 +32,24 @@ tests =  show ( myTypeRep
             , ( tyconModule myString2
             , ( tyconUQname myString2
             ))))))
-       ~=? output
+       ~?= output
 
-output = "(MyDataType Int,(DataType {tycon = \"Datatype.MyDataType\", datarep = AlgRep [MyDataType]},(\"\",(\"MyDataType\",(\"Datatype\",\"MyDataType\")))))"
\ No newline at end of file
+#if __GLASGOW_HASKELL__ >= 709
+-- In GHC 7.10 module name is stripped from DataType
+output = "(MyDataType Int,(DataType {tycon = \"MyDataType\", datarep = AlgRep [MyDataType]},(\"\",(\"MyDataType\",(\"\",\"MyDataType\")))))"
+#else
+output = "(MyDataType Int,(DataType {tycon = \"Datatype.MyDataType\", datarep = AlgRep [MyDataType]},(\"\",(\"MyDataType\",(\"Datatype\",\"MyDataType\")))))"
+#endif
+
+#else
+
+tests = show ( myTypeRep, myDataType )
+        ~?= output
+
+#if __GLASGOW_HASKELL__ >= 701
+output = "(MyDataType Int,DataType {tycon = \"Datatype.MyDataType\", datarep = AlgRep [MyDataType]})"
+#else
+output = "(Datatype.MyDataType Int,DataType {tycon = \"Datatype.MyDataType\", datarep = AlgRep [MyDataType]})"
+#endif
+
+#endif
